jaxp/src/java.xml/share/classes/javax/xml/datatype/FactoryFinder.java
changeset 27574 2e8afdf5c6fb
parent 25868 686eef1e7a79
child 42806 35843e3d5ef1
--- a/jaxp/src/java.xml/share/classes/javax/xml/datatype/FactoryFinder.java	Tue Nov 18 15:25:15 2014 -0800
+++ b/jaxp/src/java.xml/share/classes/javax/xml/datatype/FactoryFinder.java	Wed Dec 03 14:22:17 2014 +0000
@@ -50,12 +50,12 @@
     private static boolean debug = false;
 
     /**
      * Cache for properties in java.home/lib/jaxp.properties
      */
     private final static Properties cacheProps = new Properties();
 
     /**
      * Flag indicating if properties from java.home/lib/jaxp.properties
      * have been cached.
      */
     private static volatile boolean firstTime = true;
@@ -237,13 +237,13 @@
             if (debug) se.printStackTrace();
         }
 
         // try to read from $java.home/lib/jaxp.properties
         try {
             if (firstTime) {
                 synchronized (cacheProps) {
                     if (firstTime) {
                         String configFile = ss.getSystemProperty("java.home") + File.separator +
-                            "lib" + File.separator + "jaxp.properties";
+                            "conf" + File.separator + "jaxp.properties";
                         File f = new File(configFile);
                         firstTime = false;
                         if (ss.doesFileExist(f)) {
@@ -256,7 +256,7 @@
             final String factoryClassName = cacheProps.getProperty(factoryId);
 
             if (factoryClassName != null) {
-                dPrint("found in $java.home/jaxp.properties, value=" + factoryClassName);
+                dPrint("found in ${java.home}/conf/jaxp.properties, value=" + factoryClassName);
                 return newInstance(type, factoryClassName, null, true);
             }
         }
@@ -50,12 +50,12 @@
 
     /**
-     * Cache for properties in java.home/lib/jaxp.properties
+     * Cache for properties in java.home/conf/jaxp.properties
      */
     private final static Properties cacheProps = new Properties();
@@ -50,12 +50,12 @@
 
     /**
-     * Flag indicating if properties from java.home/lib/jaxp.properties
+     * Flag indicating if properties from java.home/conf/jaxp.properties
      * have been cached.
      */
@@ -237,13 +237,13 @@
         }
 
-        // try to read from $java.home/lib/jaxp.properties
+        // try to read from $java.home/conf/jaxp.properties
         try {
             if (firstTime) {